# coding=utf-8
# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from knack.help_files import helps

helps['billing'] = """
    type: group
    short-summary: Manage Azure Billing.
"""

helps['billing invoice'] = """
    type: group
    short-summary: Get billing invoices for a subscription.
"""

helps['billing period'] = """
    type: group
    short-summary: Get billing periods for a subscription.
"""

helps['billing enrollment-account'] = """
    type: group
    short-summary: Get enrollment accounts.
"""
